/*
 * acfg_errors.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"mysterious failure",
	"could not find entry",
	"do not know that information",
	"line appears before a cell has been defined",
	"syntax error",
	"a database file is missing",
	"no more entries",
	"unable to open cell database",
	"unable to build security class",
	"key doesn't meet requirements",
	"cannot determine local cell name",
    0
};

static const struct error_table et = { text, 70354688L, 11 };

static struct et_list etlink = { 0, &et};

void initialize_ACFG_error_table(void) {
    afs_add_to_error_table(&etlink);
}
