/* Machine generated file -- Do NOT edit */

#include <afsconfig.h>
#include <afs/param.h>
#include <roken.h>
#ifdef AFS_NT40_ENV
#define AFS_RXGEN_EXPORT __declspec(dllexport)
#endif /* AFS_NT40_ENV */
#include "rxstat.h"



bool_t
xdr_rpcStats(XDR *xdrs, rpcStats *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->rpcStats_val, &objp->rpcStats_len, ~0u, sizeof(afs_uint32), (xdrproc_t) xdr_afs_uint32)) {
		return (FALSE);
	}
	return (TRUE);
}


AFS_RXGEN_EXPORT
const char *RXSTATS_function_names[] = {
	"RXSTATS_RetrieveProcessRPCStats",
	"RXSTATS_RetrievePeerRPCStats",
	"RXSTATS_QueryProcessRPCStats",
	"RXSTATS_QueryPeerRPCStats",
	"RXSTATS_EnableProcessRPCStats",
	"RXSTATS_EnablePeerRPCStats",
	"RXSTATS_DisableProcessRPCStats",
	"RXSTATS_DisablePeerRPCStats",
	"RXSTATS_QueryRPCStatsVersion",
	"RXSTATS_ClearProcessRPCStats",
	"RXSTATS_ClearPeerRPCStats"
};

static char *opnames0[] = {"RXSTATS_RetrieveProcessRPCStats", "RXSTATS_RetrievePeerRPCStats", "RXSTATS_QueryProcessRPCStats", "RXSTATS_QueryPeerRPCStats", "RXSTATS_EnableProcessRPCStats", "RXSTATS_EnablePeerRPCStats", "RXSTATS_DisableProcessRPCStats", "RXSTATS_DisablePeerRPCStats", "RXSTATS_QueryRPCStatsVersion", "RXSTATS_ClearProcessRPCStats", "RXSTATS_ClearPeerRPCStats"};

char *RXSTATS_TranslateOpCode(int op)
{
	if (op < RXSTATS_LOWEST_OPCODE || op > RXSTATS_HIGHEST_OPCODE)
		return NULL;
	return opnames0[op - RXSTATS_LOWEST_OPCODE];
}
struct RXSTATS_stats *RXSTATS_OpCodeStats(int op)
{
	if (op < RXSTATS_LOWEST_OPCODE || op > RXSTATS_HIGHEST_OPCODE)
		return NULL;
	return NULL;/*0 RXSTATS_*/
}
