/* Machine generated file -- Do NOT edit */

#include <afsconfig.h>
#include <afs/param.h>
#include <roken.h>
#ifdef AFS_NT40_ENV
#define AFS_RXGEN_EXPORT __declspec(dllexport)
#endif /* AFS_NT40_ENV */
#include "volint.h"

#define VOLDUMPV2_OMITDIRS 1


bool_t
xdr_volser_status(XDR *xdrs, volser_status *objp)
{
	if (!xdr_afs_uint32(xdrs, &objp->volID)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->nextUnique)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->parentID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->cloneID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->backupID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->restoredFromID)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->maxQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->minQuota)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->owner)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->creationDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->accessDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->updateDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->expirationDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->backupDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->copyDate)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_destServer(XDR *xdrs, destServer *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->destHost)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->destPort)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->destSSID)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_volintInfo(XDR *xdrs, volintInfo *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 32, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->volid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->backupID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->parentID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->cloneID)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->status)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->copyDate)) {
		return (FALSE);
	}
	if (!xdr_u_char(xdrs, &objp->inUse)) {
		return (FALSE);
	}
	if (!xdr_u_char(xdrs, &objp->needsSalvaged)) {
		return (FALSE);
	}
	if (!xdr_u_char(xdrs, &objp->destroyMe)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->creationDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->accessDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->updateDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->backupDate)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->dayUse)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->filecount)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->maxquota)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->size)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->flags)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->spare0)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->spare1)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->spare2)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->spare3)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_volintXInfo(XDR *xdrs, volintXInfo *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 32, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->volid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->backupID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->parentID)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->cloneID)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->status)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->copyDate)) {
		return (FALSE);
	}
	if (!xdr_u_char(xdrs, &objp->inUse)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->creationDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->accessDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->updateDate)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->backupDate)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->dayUse)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->filecount)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->maxquota)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->size)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_reads, VOLINT_STATS_NUM_RWINFO_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_writes, VOLINT_STATS_NUM_RWINFO_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_fileSameAuthor, VOLINT_STATS_NUM_TIME_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_fileDiffAuthor, VOLINT_STATS_NUM_TIME_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_dirSameAuthor, VOLINT_STATS_NUM_TIME_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->stat_dirDiffAuthor, VOLINT_STATS_NUM_TIME_FIELDS, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_transDebugInfo(XDR *xdrs, transDebugInfo *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->tid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->time)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->creationTime)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->returnCode)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->volid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->partition)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->iflags)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->vflags)) {
		return (FALSE);
	}
	if (!xdr_char(xdrs, &objp->tflags)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->lastProcName, 30, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->callValid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->readNext)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->transmitNext)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->lastSendTime)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->lastReceiveTime)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_pIDs(XDR *xdrs, pIDs *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->partIds, 26, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_diskPartition(XDR *xdrs, diskPartition *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 32, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->devName, 32, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->lock_fd)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->totalUsable)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->free)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->minFree)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_diskPartition64(XDR *xdrs, diskPartition64 *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 256, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_vector(xdrs, (char *) objp->devName, 256, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_int(xdrs, &objp->lock_fd)) {
		return (FALSE);
	}
	if (!xdr_afs_int64(xdrs, &objp->totalUsable)) {
		return (FALSE);
	}
	if (!xdr_afs_int64(xdrs, &objp->free)) {
		return (FALSE);
	}
	if (!xdr_afs_int64(xdrs, &objp->minFree)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_restoreCookie(XDR *xdrs, restoreCookie *objp)
{
	if (!xdr_vector(xdrs, (char *) objp->name, 32, sizeof(char), (xdrproc_t) xdr_char)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->type)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->clone)) {
		return (FALSE);
	}
	if (!xdr_afs_uint32(xdrs, &objp->parent)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_replica(XDR *xdrs, replica *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->trans)) {
		return (FALSE);
	}
	if (!xdr_destServer(xdrs, &objp->server)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_volintSize(XDR *xdrs, volintSize *objp)
{
	if (!xdr_afs_uint64(xdrs, &objp->dump_size)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_manyDests(XDR *xdrs, manyDests *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->manyDests_val, &objp->manyDests_len, NMAXNSERVERS, sizeof(replica), (xdrproc_t) xdr_replica)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_manyResults(XDR *xdrs, manyResults *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->manyResults_val, &objp->manyResults_len, ~0u, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_transDebugEntries(XDR *xdrs, transDebugEntries *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->transDebugEntries_val, &objp->transDebugEntries_len, ~0u, sizeof(transDebugInfo), (xdrproc_t) xdr_transDebugInfo)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_volEntries(XDR *xdrs, volEntries *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->volEntries_val, &objp->volEntries_len, ~0u, sizeof(volintInfo), (xdrproc_t) xdr_volintInfo)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_partEntries(XDR *xdrs, partEntries *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->partEntries_val, &objp->partEntries_len, ~0u, sizeof(afs_int32), (xdrproc_t) xdr_afs_int32)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_volXEntries(XDR *xdrs, volXEntries *objp)
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->volXEntries_val, &objp->volXEntries_len, ~0u, sizeof(volintXInfo), (xdrproc_t) xdr_volintXInfo)) {
		return (FALSE);
	}
	return (TRUE);
}


AFS_RXGEN_EXPORT
const char *AFSVolfunction_names[] = {
	"AFSVolCreateVolume",
	"AFSVolDeleteVolume",
	"AFSVolRestore",
	"AFSVolForward",
	"AFSVolEndTrans",
	"AFSVolClone",
	"AFSVolSetFlags",
	"AFSVolGetFlags",
	"AFSVolTransCreate",
	"AFSVolDump",
	"AFSVolGetNthVolume",
	"AFSVolSetForwarding",
	"AFSVolGetName",
	"AFSVolGetStatus",
	"AFSVolSignalRestore",
	"AFSVolListPartitions",
	"AFSVolListVolumes",
	"AFSVolSetIdsTypes",
	"AFSVolMonitor",
	"AFSVolPartitionInfo",
	"AFSVolReClone",
	"AFSVolListOneVolume",
	"AFSVolNukeVolume",
	"AFSVolSetDate",
	"AFSVolXListVolumes",
	"AFSVolXListOneVolume",
	"AFSVolSetInfo",
	"AFSVolXListPartitions",
	"AFSVolForwardMultiple",
	"AFSVolConvertROtoRWvolume",
	"AFSVolGetSize",
	"AFSVolDumpV2",
	"AFSVolPartitionInfo64",
	"AFSVolSplitVolume"
};
char *AFSVolTranslateOpCode(int op)
{
	switch (op) {
		case 100:	return "AFSVolCreateVolume";
		case 101:	return "AFSVolDeleteVolume";
		case 103:	return "AFSVolForward";
		case 104:	return "AFSVolEndTrans";
		case 105:	return "AFSVolClone";
		case 106:	return "AFSVolSetFlags";
		case 107:	return "AFSVolGetFlags";
		case 108:	return "AFSVolTransCreate";
		case 110:	return "AFSVolGetNthVolume";
		case 111:	return "AFSVolSetForwarding";
		case 112:	return "AFSVolGetName";
		case 113:	return "AFSVolGetStatus";
		case 114:	return "AFSVolSignalRestore";
		case 115:	return "AFSVolListPartitions";
		case 116:	return "AFSVolListVolumes";
		case 117:	return "AFSVolSetIdsTypes";
		case 118:	return "AFSVolMonitor";
		case 119:	return "AFSVolPartitionInfo";
		case 120:	return "AFSVolReClone";
		case 121:	return "AFSVolListOneVolume";
		case 122:	return "AFSVolNukeVolume";
		case 123:	return "AFSVolSetDate";
		case 124:	return "AFSVolXListVolumes";
		case 125:	return "AFSVolXListOneVolume";
		case 126:	return "AFSVolSetInfo";
		case 127:	return "AFSVolXListPartitions";
		case 128:	return "AFSVolForwardMultiple";
		case 65536:	return "AFSVolConvertROtoRWvolume";
		case 65537:	return "AFSVolGetSize";
		case 65539:	return "AFSVolPartitionInfo64";
		default:
			return NULL;
	}
}
int AFSVolOpCodeIndex(int op)
{
	switch (op) {
		case 100:	return 0;
		case 101:	return 1;
		case 103:	return 3;
		case 104:	return 4;
		case 105:	return 5;
		case 106:	return 6;
		case 107:	return 7;
		case 108:	return 8;
		case 110:	return 10;
		case 111:	return 11;
		case 112:	return 12;
		case 113:	return 13;
		case 114:	return 14;
		case 115:	return 15;
		case 116:	return 16;
		case 117:	return 17;
		case 118:	return 18;
		case 119:	return 19;
		case 120:	return 20;
		case 121:	return 21;
		case 122:	return 22;
		case 123:	return 23;
		case 124:	return 24;
		case 125:	return 25;
		case 126:	return 26;
		case 127:	return 27;
		case 128:	return 28;
		case 65536:	return 29;
		case 65537:	return 30;
		case 65539:	return 32;
		default:
			return -1;
	}
}
