/* Machine generated file -- Do NOT edit */

#include "rmtsys.h"

#include <rx/rx.h>
#include <rx/rx_null.h>
#define RMTSYS_SERVICEID 4 /* shared between client+server */
#define AFSCONF_RMTSYSPORT 7009
#define AFSCONF_RMTSYSSERVICE "afsrmtsys"
#define NIL_PATHP "__FOO__"


bool_t
xdr_clientcred(XDR *xdrs, clientcred *objp)
{
	if (!xdr_afs_int32(xdrs, &objp->uid)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->group0)) {
		return (FALSE);
	}
	if (!xdr_afs_int32(xdrs, &objp->group1)) {
		return (FALSE);
	}
	return (TRUE);
}




bool_t
xdr_rmtbulk(XDR *xdrs, rmtbulk *objp)
{
	{
		u_int __len = (u_int) *(&objp->rmtbulk_len);
		if (!xdr_bytes(xdrs, (char **)&objp->rmtbulk_val, &__len, MAXBUFFERLEN)) {
			return (FALSE);
		}
		*(&objp->rmtbulk_len) = __len;
	}
	return (TRUE);
}


