/*
 * volerr.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"internal error releasing transaction",
	"unknown internal error",
	"badly formatted dump",
	"badly formatted dump(2)",
	"could not attach volume",
	"illegal partition",
	"could not detach volume",
	"insufficient privilege for volume operation",
	"error from volume location database",
	"bad volume name",
	"volume moved",
	"illegal volume operation",
	"volume release failed",
	"volume still in use by volserver",
	"out of virtual memory in volserver",
	"no such volume",
	"more than one read/write volume",
	"failed volume server operation",
    0
};

static const struct error_table et = { text, 1492325120L, 18 };

static struct et_list etlink = { 0, &et};

void initialize_VOLS_error_table(void) {
    afs_add_to_error_table(&etlink);
}
