/*
 * kaerrors.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"AuthServer database is inconsistent",
	"user already exists",
	"Ubik I/O error",
	"couldn't allocate entry",
	"user doesn't exist",
	"database empty or corrupted",
	"name or instance is too long or contains illegal characters",
	"bad index used internally",
	"caller not authorized",
	"answer packet too short for result",
	"request packet in error",
	"interface incompatible",
	"argument out of range",
	"administrative command called incorrectly",
	"can't create session key",
	"can't read password from terminal",
	"illegal key: bad parity or weak",
	"Ubik ClientInit failed",
	"Ubik Call failed",
	"AuthServer returned incorrect response",
	"error reading cell database",
	"cell name not found",
	"too many Ubik security objects outstanding",
	"too many keys were passed to the server's security object",
	"authentication server was passed a bad ticket",
	"unknown key version number",
	"key cache invalidated by some key change",
	"may not issue ticket for server",
	"may not authenticate as this user",
	"may not change your key",
	"not allowed to create associate",
	"can't find suitable ticket",
	"operation not allowed for associate user",
	"not a special AuthServer principal",
	"server and client clocks are badly skewed",
	"not allowed to recursively call set_password from get_time",
	"Rx failed for some reason",
	"zero length password is illegal",
	"internal error encountered in kaserver",
	"password has expired (KAPWEXPIRED)",
	"it seems like a reused password (KAREUSED)",
	"you changed it too recently; see your systems administrator (KATOOSOON)",
	"ID is locked - see your system admin (KALOCKED)",
    0
};

static const struct error_table et = { text, 180480L, 43 };

static struct et_list etlink = { 0, &et};

void initialize_KA_error_table(void) {
    afs_add_to_error_table(&etlink);
}
