/*
 * rxkad_errs.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"Security module structure inconsistent",
	"Packet too short for security challenge",
	"Security level negotiation failed",
	"Ticket length too long or too short",
	"packet had bad sequence number",
	"caller not authorized",
	"illegal key: bad parity or weak",
	"security object was passed a bad ticket",
	"ticket contained unknown key version number",
	"authentication expired",
	"sealed data inconsistent",
	"user data too long",
	"caller not authorized to use encrypted connections",
    0
};

static const struct error_table et = { text, 19270400L, 13 };

static struct et_list etlink = { 0, &et};

void initialize_RXK_error_table(void) {
    afs_add_to_error_table(&etlink);
}
