/*
 * vl_errors.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"Volume Id entry exists in vl database",
	"I/O related error",
	"Volume name entry exists in vl database",
	"Internal creation failure",
	"No such entry",
	"Vl database is empty",
	"Entry is deleted (soft delete)",
	"Volume name is illegal",
	"Index is out of range",
	"Bad volume type",
	"Illegal server number (out of range)",
	"Bad partition number",
	"Run out of space for Replication sites",
	"No such Replication server site exists",
	"Replication site already exists",
	"Parent R/W entry not found",
	"Illegal Reference Count number",
	"Vl size for attributes exceeded",
	"Bad incoming vl entry",
	"Illegal max volid increment",
	"RO/BACK id already hashed",
	"Vl entry is already locked",
	"Bad volume operation code",
	"Bad release lock type",
	"Status report: last release was aborted",
	"Invalid replication site server flag",
	"No permission access",
	"malloc(realloc) failed to alloc enough memory",
	"Wrong vldb version",
	"Index out of range",
	"Servers have the same ip address",
	"Illegal attribute mask value",
	"Database is inconsistent",
    0
};

static const struct error_table et = { text, 363520L, 33 };

static struct et_list etlink = { 0, &et};

void initialize_VL_error_table(void) {
    afs_add_to_error_table(&etlink);
}
