/*
 * pterror.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"Entry for name already exists",
	"Entry for id already exists",
	"Couldn't allocate an id for this entry",
	"Couldn't read/write the database",
	"User or group doesn't exist",
	"Permission denied",
	"No group specified",
	"No user specified",
	"Badly formed name (group prefix doesn't match owner?)",
	"argument illegal or out of range",
	"may not create more groups",
	"database needs rebuilding",
	"can't make owner an empty group",
	"database is inconsistent",
	"bad database address",
	"too many elements in group",
	"malloc failed to alloc enough memory",
	"Protection library internal error",
	"name is too long (maximum 63 characters)",
    0
};

static const struct error_table et = { text, 267264L, 19 };

static struct et_list etlink = { 0, &et};

void initialize_PT_error_table(void) {
    afs_add_to_error_table(&etlink);
}
