/*
 * uerrors.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"no quorum elected",
	"not synchronization site (should work on sync site)",
	"too many hosts",
	"I/O error writing dbase or log",
	"mysterious internal error",
	"major synchronization error",
	"file not found when processing dbase",
	"bad lock range size (must be 1)",
	"read error reprocessing log",
	"problems with host name",
	"bad operation for this transaction type",
	"two commits or aborts done to transaction",
	"operation done after abort (or commmit)",
	"no servers appear to be up",
	"premature EOF",
	"error writing log file",
	"unsupported address family -- bogus error",
	"inconsistent cell name -- bogus error",
	"security group bad or missing -- bogus error",
	"server group name bad or missing -- bogus error",
	"server uuid bad or missing -- bogus error",
	"memory allocation failure -- bogus error",
	"host not a member of server group -- bogus error",
	"too many bindings per server -- bogus error",
	"inconsistent principal name from binding -- bogus error",
	"I/O error in ubik pipe -- bogus error",
	"operation aborted to prevent dead lock (two sync sites?)",
	"rpc runtime exception caught -- bogus error",
	"vote thread pool queue operation failed -- bogus error",
	"clock skew among servers too high -- bogus error",
	"repeatedly failed to obtain ubik lock -- bogus error",
	"permission denied for attempted operation -- bogus error",
	"no space left on database device -- bogus error",
	"invalid DB pathname -- bogus error",
	"bad file descriptor -- bogus error",
	"Reinitialize called before initialize",
	"failed to initialize per client mutex",
	"failed to destroy per client mutex",
    0
};

static const struct error_table et = { text, 5376L, 38 };

static struct et_list etlink = { 0, &et};

void initialize_U_error_table(void) {
    afs_add_to_error_table(&etlink);
}
