/*
 * ktc_errors.c:
 * This file is automatically generated; please do not edit it.
 */
#include <afs/error_table.h>
static const char * const text[] = {
	"an unexpected error was encountered",
	"a buffer was too small for the response",
	"an invalid argument was passed in",
	"no such entry",
	"a pioctl failed",
	"AFS kernel pioctl doesn't exist",
	"unknown cell was passed to SetToken",
	"Cache Manager is not initialized / afsd is not running",
	"failed to send or receive session key via remote procedure call",
	"Cache Manager RPC server is not responding",
	"AFS_KTC_Mutex failure",
    0
};

static const struct error_table et = { text, 11862784L, 11 };

static struct et_list etlink = { 0, &et};

void initialize_KTC_error_table(void) {
    afs_add_to_error_table(&etlink);
}
